import matplotlib.pyplot as plt
import numpy as np
import pandas as pd
import matplotlib.gridspec as gridspec

def get_axis_limits(ax, scale):
    return ax.get_xlim()[0]*scale, ax.get_ylim()[1]*scale

def arrowed_spines(fig, ax):

    xmin, xmax = ax.get_xlim() 
    ymin, ymax = ax.get_ylim()

    # removing the default axis on all sides:
    for side in ['bottom','right','top','left']:
        ax.spines[side].set_visible(False)

    # removing the axis ticks
    plt.xticks([]) # labels 
    plt.yticks([])
    ax.xaxis.set_ticks_position('none') # tick markers
    ax.yaxis.set_ticks_position('none')

    # get width and height of axes object to compute 
    # matching arrowhead length and width
    dps = fig.dpi_scale_trans.inverted()
    bbox = ax.get_window_extent().transformed(dps)
    width, height = bbox.width, bbox.height

    # manual arrowhead width and length
    hw = 1./20.*(ymax-ymin) 
    hl = 1./20.*(xmax-xmin)
    lw = 1. # axis line width
    ohg = 0.3 # arrow overhang

    # compute matching arrowhead length and width
    yhw = hw/(ymax-ymin)*(xmax-xmin)* height/width 
    yhl = hl/(xmax-xmin)*(ymax-ymin)* width/height

    # draw x and y axis
    ax.arrow(xmin, 0, xmax-xmin, 0., fc='k', ec='k', lw = lw, 
             head_width=hw, head_length=hl, overhang = ohg, 
             length_includes_head= True, clip_on = False) 

    ax.arrow(0, ymin, 0., ymax-ymin, fc='k', ec='k', lw = lw, 
             head_width=yhw, head_length=yhl, overhang = ohg, 
             length_includes_head= True, clip_on = False)

#load data to display
arg=np.load('corrientes_ARG_T_days.npy')
mex=np.load('ocampo_MEX_T_days.npy')
dates=np.array('2011-01-01',dtype=np.datetime64)
dts=np.linspace(0,2921,2922)
dts=np.array([int(x) for x in dts])
dates=pd.DatetimeIndex(dates+dts)

argt=np.zeros((2,arg.shape[1],8,12))
mext=np.zeros((2,mex.shape[1],8,12))

years=pd.unique(dates.year)
for i in range(len(years)):
	for j in range(12):
		argt[0,:,i,j]=np.std(np.squeeze(arg[np.where((dates.year==years[i]) & (dates.month==j+1)),:]),axis=0)
		mext[0,:,i,j]=np.std(np.squeeze(mex[np.where((dates.year==years[i]) & (dates.month==j+1)),:]),axis=0)	
		argt[1,:,i,j]=np.mean(np.squeeze(arg[np.where((dates.year==years[i]) & (dates.month==j+1)),:]),axis=0)
		mext[1,:,i,j]=np.mean(np.squeeze(mex[np.where((dates.year==years[i]) & (dates.month==j+1)),:]),axis=0)

#to help see which years is best to use
argt=np.mean(argt,-1)
mext=np.mean(mext,-1)

args=np.squeeze(arg[np.where(dates.year==2012),0])
mexs=np.squeeze(mex[np.where(dates.year==2012),2])

#number of days per month
days1=[]
for i in range(12):
        days1.append(len(np.where((dates.year==2012)&(dates.month==i+1))[0]))
labels=[] 
count=0
for i in range(len(days1)):
        labels.append(count+int(days1[i]/2))
        count+=days1[i]

#start plotting
cm=1/2.54
degree_sign= u'\N{DEGREE SIGN}'
c=degree_sign + 'C'
fontsize=6
fontype='Helvetica'
fig=plt.figure(constrained_layout=True,figsize=(8.8*cm,10*cm))
widths=[8.8*cm]
heights=[5*cm,2]
spec=fig.add_gridspec(ncols=1,nrows=2,width_ratios=widths,height_ratios=heights)

ylabel=[0,10,args.mean(),30]
ylabels=['0' + c,'10' + c,str(round(args.mean(),1)) + c,'30' + c]

ax3=fig.add_subplot(spec[0])
ax3.set_ylim(0,35)
ax3.set_xlim(0,366)
d=np.linspace(1,366,366)
ax3.scatter(d,args,s=0.7,color='k')
ax3.axis('on')
ax3.set_ylabel('Daily Temperature',fontsize=fontsize+1)
ax3.set_xticks(labels)
ax3.set_xticklabels(['Jan','Feb','Mar','Apr','May','Jun','Jul','Aug','Sep','Oct','Nov','Dec'])
ax3.tick_params(labelsize=fontsize)

start=0
for i in range(12):
	ax3.plot(np.linspace(start,start+days1[i],days1[i]),np.ones((days1[i],))*np.mean(arg[np.where((dates.year==2012) & (dates.month==i+1)),0]),c='k',alpha=0.5) 
	ax3.fill_between(d[start:start+days1[i]],args[start:start+days1[i]],np.mean(arg[np.where((dates.year==2012) & (dates.month==i+1)),0]),color='r',alpha=0.5) 
	start+=days1[i]
ax3.axhline(args.mean(),ls='-',color='gray',alpha=0.5)
ax3.annotate('Grid cell in Corrientes, Argentina',(1,1),fontsize=fontsize)
ax3.set_yticks(ylabel)
ax3.set_yticklabels(ylabels)

ylabel=[0,10,mexs.mean(),30]
ylabels=['0' + c,'10' + c,str(round(mexs.mean(),1)) + c,'30' + c]

ax4=fig.add_subplot(spec[1])
ax4.set_ylim(0,35)
ax4.set_xlim(0,366)
ax4.scatter(d,mexs,s=0.7,color='k')
ax4.axis('on')
ax4.set_xticks(labels)
ax4.set_xticklabels(['Jan','Feb','Mar','Apr','May','Jun','Jul','Aug','Sep','Oct','Nov','Dec'])
ax4.set_ylabel('Daily Temperature',fontsize=fontsize+1)
ax4.tick_params(labelsize=fontsize)
start=0
for i in range(12):
	ax4.plot(np.linspace(start,start+days1[i],days1[i]),np.ones((days1[i],))*np.mean(mex[np.where((dates.year==2012) & (dates.month==i+1)),2]),c='k',alpha=0.5)
	ax4.fill_between(d[start:start+days1[i]],mexs[start:start+days1[i]],np.mean(mex[np.where((dates.year==2012) & (dates.month==i+1)),2]),color='b',alpha=0.5)
	start+=days1[i]
ax4.axhline(mexs.mean(),ls='-',color='gray',alpha=0.5)
ax4.annotate('Grid cell in Michoacán De Ocampo, Mexico',(1,1),fontsize=fontsize)
ax4.set_yticks(ylabel)
ax4.set_yticklabels(ylabels)

plt.savefig('Fig_1.pdf',dpi=600)
plt.close()


